Class: Mdm::Loot

Inherits:
ActiveRecord::Base
  • Object
show all
Defined in:
app/models/mdm/loot.rb

Overview

Loot gathered from #host or #service such as files to prove you were on the system or to crack later to gain sessions on other machines in the network.

Constant Summary collapse

RELATIVE_SEARCH_FIELDS =

CONSTANTS

[
    'ltype',
    'name',
    'info',
    'data'
]

Instance Attribute Summary collapse

Instance Attribute Details

#content_type ⇒ String

The mime/content type of the file at #path. Used to server the file correctly so browsers understand whether to render or download the file.

Returns:

  • (String)


# File 'app/models/mdm/loot.rb', line 73


#created_at ⇒ DateTime

When the loot was created.

Returns:

  • (DateTime)


# File 'app/models/mdm/loot.rb', line 79


#data ⇒ String

Loot data not stored in file at #path.

Returns:

  • (String)


# File 'app/models/mdm/loot.rb', line 84


#exploit_attempt ⇒ Mdm::ExploitAttempt

Exploit attempt where this loot was gathered.

Returns:



24
25
26
# File 'app/models/mdm/loot.rb', line 24

has_one :exploit_attempt,
class_name: 'Mdm::ExploitAttempt',
inverse_of: :loot

#host ⇒ Mdm::Host

The host from which the loot was gathered.

Returns:



32
33
34
# File 'app/models/mdm/loot.rb', line 32

belongs_to :host,
class_name: 'Mdm::Host',
inverse_of: :loots

#info ⇒ String

Information about the loot.

Returns:

  • (String)


# File 'app/models/mdm/loot.rb', line 94


#ltype ⇒ String

The type of loot

Returns:

  • (String)


# File 'app/models/mdm/loot.rb', line 89


#module_run ⇒ MetasploitDataModels::ModuleRun

The run of Metasploit content that acquired the loot



40
41
42
43
# File 'app/models/mdm/loot.rb', line 40

belongs_to :module_run,
class_name: 'MetasploitDataModels::ModuleRun',
foreign_key: :module_run_id,
inverse_of: :loots

#name ⇒ String

The name of the loot.

Returns:

  • (String)


# File 'app/models/mdm/loot.rb', line 99


#path ⇒ String

The on-disk path to the loot file.

Returns:

  • (String)


# File 'app/models/mdm/loot.rb', line 104


#service ⇒ Mdm::Service

The service running on the #host from which the loot was gathered.

Returns:



49
50
51
# File 'app/models/mdm/loot.rb', line 49

belongs_to :service,
class_name: 'Mdm::Service',
inverse_of: :loots

#updated_at ⇒ DateTime

The last time the loot was updated.

Returns:

  • (DateTime)


# File 'app/models/mdm/loot.rb', line 109


#vuln_attempt ⇒ Mdm::VulnAttempt

Vuln attempt that gathered this loot.

Returns:



57
58
59
# File 'app/models/mdm/loot.rb', line 57

has_one :vuln_attempt,
class_name: 'Mdm::VulnAttempt',
inverse_of: :loot

#workspace ⇒ Mdm::Workspace

The workspace in which the loot is stored and the #host exists.

Returns:



65
66
67
# File 'app/models/mdm/loot.rb', line 65

belongs_to :workspace,
class_name: 'Mdm::Workspace',
inverse_of: :loots