Class: Mdm::Profile

Inherits:
ActiveRecord::Base
  • Object
show all
Defined in:
app/models/mdm/profile.rb

Overview

User settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#active ⇒ true, false

Whether this is the currently active profile.

Returns:

  • (true) —

    if this is the active profile.

  • (false) —

    if this profile is inactive and another profile is active.



# File 'app/models/mdm/profile.rb', line 7

#created_at ⇒ DateTime

When this profile was created.

Returns:

  • (DateTime)


# File 'app/models/mdm/profile.rb', line 13

#name ⇒ String

Name of this profile to distinguish it from other profiles.

Returns:

  • (String)


# File 'app/models/mdm/profile.rb', line 18

#owner ⇒ '<system>', String

Owner of this profile.

Returns:

  • ('<system>') —

    System-wide profile for all users.

  • (String) —

    Name of user that uses this profile.



# File 'app/models/mdm/profile.rb', line 23

#updated_at ⇒ DateTime

The last time this profile was updated.

Returns:

  • (DateTime)


# File 'app/models/mdm/profile.rb', line 29

Instance Method Details

#settings ⇒ Hash

Global settings.

Returns:

  • (Hash)


41
# File 'app/models/mdm/profile.rb', line 41

serialize :settings, MetasploitDataModels::Base64Serializer.new