Class: Mdm::VulnAttempt

Inherits:
ApplicationRecord
  • Object
show all
Defined in:
app/models/mdm/vuln_attempt.rb

Overview

An attempt to exploit a #vuln.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#attempted_atDateTime

When this attempt was made.

Returns:

  • (DateTime)


# File 'app/models/mdm/vuln_attempt.rb', line 38

#check_codeString?

The check code returned by the module's check method, if this attempt was a vulnerability check rather than an exploitation attempt.

Returns:

  • (String)

    one of 'vulnerable', 'appears', 'safe', 'detected', 'unknown'

  • (nil)

    if this was an exploitation attempt, not a check



# File 'app/models/mdm/vuln_attempt.rb', line 66

#check_detailString?

The human-readable message from the module's check method describing why the target was determined to be vulnerable, safe, etc.

Returns:

  • (String)

    if #check_code is present.

  • (nil)

    if this was an exploitation attempt, not a check



# File 'app/models/mdm/vuln_attempt.rb', line 73

#exploitedtrue, false

Whether this attempt was successful.

Returns:

  • (true)

    if #vuln was exploited.

  • (false)

    if #vuln was not exploited.



# File 'app/models/mdm/vuln_attempt.rb', line 43

#fail_detailString?

Long details about why this attempt failed.

Returns:



# File 'app/models/mdm/vuln_attempt.rb', line 49

#fail_reasonString?

Short reason why this attempt failed.

Returns:



# File 'app/models/mdm/vuln_attempt.rb', line 55

#moduleString

Full name of exploit Metasploit Module that was used in this attempt.

Returns:

  • (String)


# File 'app/models/mdm/vuln_attempt.rb', line 61

#usernameString

The name of the user that made this attempt.

Returns:

  • (String)


# File 'app/models/mdm/vuln_attempt.rb', line 80

Instance Method Details

#lootMdm::Loot?

Loot gathered from this attempt.

Returns:



12
13
14
15
# File 'app/models/mdm/vuln_attempt.rb', line 12

belongs_to :loot,
class_name: 'Mdm::Loot',
optional: true,
inverse_of: :vuln_attempt

#sessionMdm::Session?

The session opened by this attempt.

Returns:



21
22
23
24
# File 'app/models/mdm/vuln_attempt.rb', line 21

belongs_to :session,
class_name: 'Mdm::Session',
optional: true,
inverse_of: :vuln_attempt

#vulnMdm::Vuln

The vulnerability that this attempt was exploiting.

Returns:



29
30
31
32
# File 'app/models/mdm/vuln_attempt.rb', line 29

belongs_to :vuln,
class_name: 'Mdm::Vuln',
counter_cache: :vuln_attempt_count,
inverse_of: :vuln_attempts