Class: Mdm::User
- Inherits:
-
ApplicationRecord
- Object
- ApplicationRecord
- Mdm::User
- Extended by:
- MetasploitDataModels::SerializedPrefs
- Defined in:
- app/models/mdm/user.rb
Overview
A user of metasploit-framework or metasploit-pro.
HTTP Proxy collapse
-
#http_proxy_host ⇒ String?
Proxy host.
-
#http_proxy_pass ⇒ String?
Password used to login as #http_proxy_user to proxy.
-
#http_proxy_port ⇒ String, ...
Port on which proxy run on #http_proxy_host.
-
#http_proxy_user ⇒ String?
User used to log into proxy.
Nexpose collapse
-
#nexpose_host ⇒ String?
Host name for server running Nexpose.
-
#nexpose_pass ⇒ String?
Password to log into Nexpose.
-
#nexpose_port ⇒ String, Integer. nil
Port on #nexpose_host on which Nexpose is running.
-
#nexpose_user ⇒ String?
User used to log into Nexpose.
Nexpose Authenticated Scan Credentials collapse
Instance Attribute Summary collapse
-
#admin ⇒ false, true
Whether this user is an administrator.
-
#company ⇒ String?
Company at which user works.
-
#created_at ⇒ DateTime
When the user was created.
-
#crypted_password ⇒ String
Hashed password (salted with #password_salt) by Authlogic in metasploit-pro.
-
#email ⇒ String?
The user's email address.
-
#fullname ⇒ String?
The user's normal human name.
-
#last_login_address ⇒ String?
Last IP address from which this user logged in.
-
#password_salt ⇒ String
Salt used when hashing password into #crypted_password by Authlogic in metasploit-pro.
-
#persistence_token ⇒ String
Token used for session and cookie when user is logged using Authlogic in metasploit-pro.
-
#phone ⇒ String?
Phone number for user.
-
#session_key ⇒ String?
Holds
session[:session_id]so user can only be logged in once. -
#sso_enabled ⇒ Boolean
Does this user authenticate via SSO.
-
#time_zone ⇒ String?
User's preferred time zone.
-
#updated_at ⇒ DateTime
When the user was last updated.
-
#username ⇒ String
Username for this user.
Method Summary
Methods included from MetasploitDataModels::SerializedPrefs
serialized_prefs_attr_accessor
Instance Attribute Details
#admin ⇒ false, true
Whether this user is an administrator. Administrator permissions are only enforced in metasploit-pro through the controllers.
|
|
# File 'app/models/mdm/user.rb', line 47
|
#company ⇒ String?
Company at which user works.
|
|
# File 'app/models/mdm/user.rb', line 55
|
#created_at ⇒ DateTime
When the user was created.
|
|
# File 'app/models/mdm/user.rb', line 60
|
#crypted_password ⇒ String
Hashed password (salted with #password_salt) by Authlogic in metasploit-pro.
|
|
# File 'app/models/mdm/user.rb', line 65
|
#email ⇒ String?
The user's email address.
|
|
# File 'app/models/mdm/user.rb', line 70
|
#fullname ⇒ String?
The user's normal human name.
|
|
# File 'app/models/mdm/user.rb', line 75
|
#http_proxy_host ⇒ String?
Proxy host.
161 |
# File 'app/models/mdm/user.rb', line 161 serialized_prefs_attr_accessor :http_proxy_host |
#http_proxy_pass ⇒ String?
Password used to login as #http_proxy_user to proxy.
167 |
# File 'app/models/mdm/user.rb', line 167 serialized_prefs_attr_accessor :http_proxy_pass |
#http_proxy_port ⇒ String, ...
Port on which proxy run on #http_proxy_host.
173 |
# File 'app/models/mdm/user.rb', line 173 serialized_prefs_attr_accessor :http_proxy_port |
#http_proxy_user ⇒ String?
User used to log into proxy.
179 |
# File 'app/models/mdm/user.rb', line 179 serialized_prefs_attr_accessor :http_proxy_user |
#last_login_address ⇒ String?
specifically NOT last_login_ip to prevent confusion with AuthLogic magic columns (which dont work for serialized fields)
Last IP address from which this user logged in. Used to report currently active user session's IP when the user
is logged off because theire session[:session_id] does not match #session_key.
141 |
# File 'app/models/mdm/user.rb', line 141 serialized_prefs_attr_accessor :last_login_address |
#nexpose_creds_pass ⇒ String?
223 |
# File 'app/models/mdm/user.rb', line 223 serialized_prefs_attr_accessor :nexpose_creds_pass |
#nexpose_creds_type ⇒ String?
227 |
# File 'app/models/mdm/user.rb', line 227 serialized_prefs_attr_accessor :nexpose_creds_type |
#nexpose_creds_user ⇒ String?
231 |
# File 'app/models/mdm/user.rb', line 231 serialized_prefs_attr_accessor :nexpose_creds_user |
#nexpose_host ⇒ String?
Host name for server running Nexpose.
193 |
# File 'app/models/mdm/user.rb', line 193 serialized_prefs_attr_accessor :nexpose_host |
#nexpose_pass ⇒ String?
Password to log into Nexpose.
199 |
# File 'app/models/mdm/user.rb', line 199 serialized_prefs_attr_accessor :nexpose_pass |
#nexpose_port ⇒ String, Integer. nil
Port on #nexpose_host on which Nexpose is running.
205 |
# File 'app/models/mdm/user.rb', line 205 serialized_prefs_attr_accessor :nexpose_port |
#nexpose_user ⇒ String?
User used to log into Nexpose.
211 |
# File 'app/models/mdm/user.rb', line 211 serialized_prefs_attr_accessor :nexpose_user |
#password_salt ⇒ String
Salt used when hashing password into #crypted_password by Authlogic in metasploit-pro.
|
|
# File 'app/models/mdm/user.rb', line 80
|
#persistence_token ⇒ String
Token used for session and cookie when user is logged using Authlogic in metasploit-pro.
|
|
# File 'app/models/mdm/user.rb', line 85
|
#phone ⇒ String?
Phone number for user.
|
|
# File 'app/models/mdm/user.rb', line 90
|
#session_key ⇒ String?
Holds session[:session_id] so user can only be logged in once. Only enforced in metasploit-pro.
147 |
# File 'app/models/mdm/user.rb', line 147 serialized_prefs_attr_accessor :session_key |
#sso_enabled ⇒ Boolean
Does this user authenticate via SSO
|
|
# File 'app/models/mdm/user.rb', line 105
|
#time_zone ⇒ String?
User's preferred time zone.
127 |
# File 'app/models/mdm/user.rb', line 127 serialized_prefs_attr_accessor :time_zone |
#updated_at ⇒ DateTime
When the user was last updated.
|
|
# File 'app/models/mdm/user.rb', line 95
|
#username ⇒ String
Username for this user. Used to log into metasploit-pro.
|
|
# File 'app/models/mdm/user.rb', line 100
|