Class: Mdm::VulnAttempt

Inherits:
ActiveRecord::Base
  • Object
show all
Defined in:
app/models/mdm/vuln_attempt.rb

Overview

An attempt to exploit a #vuln.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#attempted_at ⇒ DateTime

When this attempt was made.

Returns:

  • (DateTime)


# File 'app/models/mdm/vuln_attempt.rb', line 36


#exploited ⇒ true, false

Whether this attempt was successful.

Returns:

  • (true) —

    if #vuln was exploited.

  • (false) —

    if #vuln was not exploited.



# File 'app/models/mdm/vuln_attempt.rb', line 41


#fail_detail ⇒ String?

Long details about why this attempt failed.

Returns:



# File 'app/models/mdm/vuln_attempt.rb', line 47


#fail_reason ⇒ String?

Short reason why this attempt failed.

Returns:



# File 'app/models/mdm/vuln_attempt.rb', line 53


#module ⇒ String

Full name of exploit Metasploit Module that was used in this attempt.

Returns:

  • (String)


# File 'app/models/mdm/vuln_attempt.rb', line 59


#username ⇒ String

The name of the user that made this attempt.

Returns:

  • (String)


# File 'app/models/mdm/vuln_attempt.rb', line 64


Instance Method Details

#loot ⇒ Mdm::Loot?

Loot gathered from this attempt.

Returns:



12
13
14
# File 'app/models/mdm/vuln_attempt.rb', line 12

belongs_to :loot,
class_name: 'Mdm::Loot',
inverse_of: :vuln_attempt

#session ⇒ Mdm::Session?

The session opened by this attempt.

Returns:



20
21
22
# File 'app/models/mdm/vuln_attempt.rb', line 20

belongs_to :session,
class_name: 'Mdm::Session',
inverse_of: :vuln_attempt

#vuln ⇒ Mdm::Vuln

The vulnerability that this attempt was exploiting.

Returns:



27
28
29
30
# File 'app/models/mdm/vuln_attempt.rb', line 27

belongs_to :vuln,
class_name: 'Mdm::Vuln',
counter_cache: :vuln_attempt_count,
inverse_of: :vuln_attempts